@@ -1,4 +1,4 @@
-from mock import MagicMock
+from unittest.mock import MagicMock
 from jupyterlab_autoversion.extension import load_jupyter_server_extension
 
 
